<?php 

function ebor_theme_customize($wp_customize){
	$wp_customize->remove_section( 'colors' );
}
add_action('customize_register', 'ebor_theme_customize', 99999);

/**
 * Build theme options
 * Uses the Ebor_Options class found in the ebor-framework plugin
 * Panels are WP 4.0+!!!
 * 
 * @since 1.0.0
 * @author tommusrhodus
 */
if( class_exists('Ebor_Options') ){
	$ebor_options = new Ebor_Options;
	
	/**
	 * Variables
	 */
	$theme = wp_get_theme();
	$theme_name = $theme->get( 'Name' );
	$directory = trailingslashit(get_template_directory_uri());
	$social_options = ebor_get_social_icons();
	$header_layouts = ebor_get_header_options();
	$site_layouts = array(
		'full-layout' => 'Full-Width',
		'box-layout' => 'Boxed'	
	);
	
	$footer_default = 'Copyright 2014 TommusRhodus';
	$subtitle_default = 'We are a digital photography studio specializing in landscape, advertorial and conceptual photography, based in New York. We love to turn ideas into beautiful things.';
	$portfolio_layouts = array(
		'masonry' => 'Masonry',
		'classic' => 'Classic Masonry',
		'full' => 'FullWidth Grid',
		'masonry-lightbox' => 'Masonry Lightbox',
		'classic-lightbox' => 'Classic Masonry Lightbox',
		'full-lightbox' => 'FullWidth Grid Lightbox'
	);
	$blog_layouts = array(
		'stripes' => 'No Sidebar',
		'grid' => 'Grid Blog',
		'grid-sidebar' => 'Grid Blog & Sidebar',
		'classic' => 'Classic Blog',
		'classic-sidebar' => 'Classic Blog & Sidebar',
		'classic-half' => '2 Column Classic Blog',
		'classic-full' => 'Classic Blog (Full Posts)',
		'classic-sidebar-full' => 'Classic Blog & Sidebar (Full Posts)',
		'classic-half-full' => '2 Column Classic Blog (Full Posts)'
	);
	$fonts_description = 'Fonts: ' . $theme_name . ' uses Google Fonts, <a href="https://www.google.com/fonts" target="_blank">all of which are viewable here</a>. Unlike some themes, ' . $theme_name . ' does not load all of these fonts into these options, in avoiding this ' . $theme_name . ' can work faster and more reliably.<br /><br />
	
	To customize the fonts on your website use the URL above and the inputs below accordingly. Full details of this process (and the default values) can be found in the theme documentation!';
	
	/**
	 * Panels
	 * 
	 * add_panel($name, $priority, $description)
	 * 
	 * @since 1.0.0
	 * @author tommusrhodus
	 */
	$ebor_options->add_panel( $theme_name . ': Demo Data', 5, '');
	$ebor_options->add_panel( $theme_name . ': Styling Settings', 205, 'All of the controls in this section directly relate to the styling page of ' . $theme_name);
	$ebor_options->add_panel( $theme_name . ': Header Settings', 215, 'All of the controls in this section directly relate to the header and logos of ' . $theme_name);
	$ebor_options->add_panel( $theme_name . ': Blog Settings', 225, 'All of the controls in this section directly relate to the control of blog items within ' . $theme_name);
	$ebor_options->add_panel( $theme_name . ': Portfolio Settings', 230, 'All of the controls in this section directly relate to the control of portfolio items within ' . $theme_name);
	$ebor_options->add_panel( $theme_name . ': Footer Settings', 290, 'All of the controls in this section directly relate to the control of the footer within ' . $theme_name);
	
	/**
	 * Sections
	 * 
	 * add_section($name, $title, $priority, $panel, $description)
	 * 
	 * @since 1.0.0
	 * @author tommusrhodus
	 */
	//Demo Data
	$ebor_options->add_section('demo_data_section', 'Import Demo Data', 10, $theme_name . ': Demo Data', '<strong>Please read this before importing demo data via this control:</strong><br /><br />The demo data this will install includes images from my demo site with <strong>heavy blurring applied</strong> this is due to licensing restrictions. Simply replace these images with your own.<br /><br />');
	
	//Styling Sections
	$ebor_options->add_section('site_section', 'Site Layout', 1, $theme_name . ': Styling Settings');
	$ebor_options->add_section('fonts_section', 'Fonts', 5, $theme_name . ': Styling Settings', $fonts_description);
	$ebor_options->add_section('colours_section', 'Colours', 10, $theme_name . ': Styling Settings');
	$ebor_options->add_section('favicon_section', 'Favicons', 30, $theme_name . ': Styling Settings');
	$ebor_options->add_section('custom_css_section', 'Custom CSS', 40, $theme_name . ': Styling Settings');
	
	//Blog Sections
	$ebor_options->add_section('blog_settings', 'Blog Settings', 1, $theme_name . ': Blog Settings');
	$ebor_options->add_section('blog_text_section', 'Blog Texts', 5, $theme_name . ': Blog Settings');
	$ebor_options->add_section('blog_layout_section', 'Blog Layout', 10, $theme_name . ': Blog Settings');
	
	//Portfolio Sections
	$ebor_options->add_section('portfolio_text_section', 'Portfolio Texts', 5, $theme_name . ': Portfolio Settings');
	$ebor_options->add_section('portfolio_layout_section', 'Portfolio Layout', 10, $theme_name . ': Portfolio Settings');
	
	//Header Settings
	$ebor_options->add_section('header_layout_section', 'Header Layout', 5, $theme_name . ': Header Settings', 'This setting controls the theme header site-wide. If you need to you can override this setting on specific posts and pages from within that posts edit screen.');
	$ebor_options->add_section('logo_settings_section', 'Logo Settings', 10, $theme_name . ': Header Settings');
	$ebor_options->add_section('subheader_settings_section', 'Sub-Header Settings', 30, $theme_name . ': Header Settings');
	$ebor_options->add_section('header_social_settings_section', 'Header Icons Settings', 40, $theme_name . ': Header Settings', 'These social icons are only shown in certain header layouts.');
	
	//Footer Settings
	$ebor_options->add_section('footer_layout_section', 'Footer Layout', 5, $theme_name . ': Footer Settings', 'This setting controls the theme footer site-wide. If you need to you can override this setting on specific posts and pages from within that posts edit screen.');
	$ebor_options->add_section('subfooter_settings_section', 'Sub-Footer Settings', 30, $theme_name . ': Footer Settings');
	$ebor_options->add_section('footer_social_settings_section', 'Footer Icons Settings', 40, $theme_name . ': Footer Settings', 'These social icons are only shown in certain footer layouts.');
	$ebor_options->add_section('cta_footer_settings_section', 'Call To Action Footer Layout Settings', 50, $theme_name . ': Footer Settings', 'These settings are for the Call To Action footer layout, this footer style also uses a navigation menu that can be set to the "footer" menu location in "appearance" -> "menus".');
	$ebor_options->add_section('social_footer_settings_section', 'Centered Social Footer Layout Settings', 60, $theme_name . ': Footer Settings', 'These settings are for the Centered Social Footer layout, this footer style also uses the footer social icons settings');
	
	/**
	 * Settings (The Actual Options)
	 * Repeated settings are stepped using a for() loop and counter
	 * 
	 * add_setting($type, $option, $title, $section, $default, $priority, $select_options)
	 * 
	 * @since 1.0.0
	 * @author tommusrhodus
	 */
	//Favicons
	$ebor_options->add_setting('image', 'custom_favicon', 'Custom Favicon Upload (Use .png)', 'favicon_section', '', 10);
	$ebor_options->add_setting('image', 'mobile_favicon', 'Mobile Favicon Upload (Use .png)', 'favicon_section', '', 15);
	$ebor_options->add_setting('image', '72_favicon', '72x72px Favicon Upload (Use .png)', 'favicon_section', '', 20);
	$ebor_options->add_setting('image', '114_favicon', '114x114px Favicon Upload (Use .png)', 'favicon_section', '', 25);
	$ebor_options->add_setting('image', '144_favicon', '144x144px Favicon Upload (Use .png)', 'favicon_section', '', 30);
	
	//Demo Data
	$ebor_options->add_setting('demo_import', 'demo_import', 'Import Demo Data', 'demo_data_section', '', 10);
	
	//Site Layout
	$ebor_options->add_setting('select', 'site_layout', 'Site Layout', 'site_section', 'full-layout', 10, $site_layouts);
	
	//Fonts
	$ebor_options->add_setting('input', 'body_font', 'Body Font', 'fonts_section', 'Dosis', 10);
	$ebor_options->add_setting('textarea', 'body_font_url', 'Body Font URL Parameter', 'fonts_section', 'http://fonts.googleapis.com/css?family=Dosis:200,300,400,500,600,700,800', 15);
	
	//Colour Options
	$ebor_options->add_setting('color', 'color_background', 'Background Colour', 'colours_section', '#ffffff', 1);
	$ebor_options->add_setting('color', 'color_highlight', 'Highlight Colour', 'colours_section', '#57a4a4', 5);
	$ebor_options->add_setting('color', 'color_highlight_hover', 'Highlight Hover Colour', 'colours_section', '#4b8e8e', 10);
	
	$ebor_options->add_setting('color', 'color_text', 'Text Colour', 'colours_section', '#5c5c5c', 15);
	$ebor_options->add_setting('color', 'color_headings', 'Headings Colour', 'colours_section', '#4e4e4e', 20);
	
	$ebor_options->add_setting('color', 'color_nav_dropdown_background', 'Nav Dropdown Background Colour', 'colours_section', '#3a3a3a', 25);
	
	$ebor_options->add_setting('color', 'color_footer', 'Footer Background Colour', 'colours_section', '#1e1f20', 50);
	$ebor_options->add_setting('color', 'color_subfooter', 'Sub Footer Background Colour', 'colours_section', '#1a1a1b', 55);

	
	//Styling Options
	$ebor_options->add_setting('textarea', 'custom_css', 'Custom CSS', 'custom_css_section', '', 30);
	
	//Blog Options
	$ebor_options->add_setting('input', 'blog_continue', '"Read More" Text', 'blog_text_section', 'Continue reading →', 10);
	$ebor_options->add_setting('select', 'blog_layout', 'Blog Index Layout', 'blog_layout_section', 'grid-sidebar', 10, $blog_layouts);

	
	//Portfolio options
	$ebor_options->add_setting('select', 'portfolio_layout', 'Portfolio Layout', 'portfolio_layout_section', 'portfolio-fullwidth', 10, $portfolio_layouts);
	$ebor_options->add_setting('checkbox', 'portfolio_filters', 'Portfolio Archives: Show Filters?', 'portfolio_layout_section', '1', 20);
	$ebor_options->add_setting('input', 'portfolio_title', 'Portfolio Archives: Title', 'portfolio_text_section', 'Hello! We are Finch Studio', 20);
	$ebor_options->add_setting('textarea', 'portfolio_subtitle', 'Portfolio Archives: Subtitle', 'portfolio_text_section', $subtitle_default, 30);
	
	//Logo Options
	$ebor_options->add_setting('image', 'custom_logo', 'Logo', 'logo_settings_section', $directory . 'style/images/logo.png', 5);
	$ebor_options->add_setting('image', 'custom_logo_retina', 'Retina Logo', 'logo_settings_section', $directory . 'style/images/logo@2x.png', 10);
	$ebor_options->add_setting('range', 'logo_height', 'Logo Height (63 Default)', 'logo_settings_section', '63', 15, array('min' => '0', 'max' => '120', 'step' => '1'));
	
	//Header Layout Option
	$ebor_options->add_setting('select', 'header_layout', 'Global Header Layout', 'header_layout_section', 'overlay', 5, $header_layouts);
	
	//Subheader Options
	$ebor_options->add_setting('input', 'header_phone', 'Phone No.', 'subheader_settings_section', '+00 (123) 456 78 90 ', 10);
	$ebor_options->add_setting('input', 'header_email', 'Email', 'subheader_settings_section', 'first.last@email.com', 20);
	
	//Header Icons
	for( $i = 1; $i < 7; $i++ ){
		$ebor_options->add_setting('select', 'header_social_icon_' . $i, 'Header Social Icon ' . $i, 'header_social_settings_section', 'none', 20 + $i + $i, $social_options);
		$ebor_options->add_setting('input', 'header_social_url_' . $i, 'Header Social URL ' . $i, 'header_social_settings_section', '', 21 + $i + $i);
	}
	
	//Footer Options
	$ebor_options->add_setting('textarea', 'copyright', 'Copyright Message', 'subfooter_settings_section', $footer_default, 20);
	
	//background image
	$ebor_options->add_setting('image', 'body_background', 'Body Wrapper Background', 'background_image', '', 20);
}