<?php

class AQ_Blog_Block extends AQ_Block {
	
	//set and create block
	function __construct() {
		$block_options = array(
			'name' => 'Blog Feed',
			'size' => 'span12',
			'block_description' => 'Add a feed of blog posts to the page.',
			'block_category' => 'feeds',
			'block_icon' => '<i class="fa fa-fw fa-pencil"></i>'
		);
		parent::__construct('aq_blog_block', $block_options);
	}//end construct
	
	function form($instance) {
		$defaults = array(
			'pppage' => '6',
			'filter' => 'all',
			'type' => 'grid-sidebar',
			'pagination' => 0
		);
		
		$instance = wp_parse_args($instance, $defaults);
		extract($instance);
		
		$args = array(
			'orderby'                  => 'name',
			'hide_empty'               => 0,
			'hierarchical'             => 1,
			'taxonomy'                 => 'category'
		); 
			
		$filter_options = get_categories( $args );
		
		$blog_types = array(
			'stripes' => 'No Sidebar',
			'grid' => 'Grid Blog',
			'grid-sidebar' => 'Grid Blog & Sidebar',
			'classic' => 'Classic Blog',
			'classic-sidebar' => 'Classic Blog & Sidebar',
			'classic-half' => '2 Column Classic Blog',
			'classic-full' => 'Classic Blog (Full Posts)',
			'classic-sidebar-full' => 'Classic Blog & Sidebar (Full Posts)',
			'classic-half-full' => '2 Column Classic Blog (Full Posts)'
		);
	?>
		
		<p class="description">Blog Style</p>
		<?php echo aq_field_select('type', $block_id, $blog_types, $type) ?>
		
		<p class="description">Posts Per Page</p>
		<?php echo aq_field_input('pppage', $block_id, $pppage, $size = 'full', $type = 'number') ?>
		
		<p class="description">Show posts from a specific category?</p>
		<?php echo ebor_portfolio_field_select('filter', $block_id, $filter_options, $filter) ?>
		
		<hr />
		
		<div class="ebor-checkbox cf">
			<?php echo aq_field_checkbox('pagination', $block_id, $pagination) ?>
			<p class="description">Show Pagination?</p>
		</div>
		
	<?php
	}//end form
	
	function block($instance) {
		extract($instance);
		
		// Fix for pagination
		if( is_front_page() ) { 
			$paged = ( get_query_var( 'page' ) ) ? get_query_var( 'page' ) : 1; 
		} else { 
			$paged = ( get_query_var( 'paged' ) ) ? get_query_var( 'paged' ) : 1; 
		}
		
		/**
		 * Setup post query
		 */
		$query_args = array(
			'post_type' => 'post',
			'posts_per_page' => $pppage,
			'paged' => $paged
		);
		
		/**
		 * Set up category query if needed
		 */
		if (!( $filter == 'all' )) {
			
			if( function_exists( 'icl_object_id' ) ){
				$filter = (int)icl_object_id( $filter, 'category', true);
			}
			
			$query_args['tax_query'] = array(
				array(
					'taxonomy' => 'category',
					'field' => 'id',
					'terms' => $filter
				)
			);
			
		}
	
		$block_query = new WP_Query( $query_args );
		
		if( 'grid-sidebar' == $type ) :
	?>
		
		<div class="row">
			<div class="col-sm-8 content">
			
				<div class="blog-posts grid-blog col2">
					<?php 
						if ( $block_query->have_posts() ) : while ( $block_query->have_posts() ) : $block_query->the_post();
							
							/**
							 * Get blog posts by blog layout.
							 */
							get_template_part('loop/content-post', 'grid');
						
						endwhile;	
						else : 
							
							/**
							 * Display no posts message if none are found.
							 */
							get_template_part('loop/content','none');
							
						endif;
					?>
				</div><!-- /.blog-posts -->
				
				<?php
					if( 1 == $pagination )
						echo function_exists('ebor_pagination') ? ebor_pagination($block_query->max_num_pages) : posts_nav_link();
						
					wp_reset_query();
				?>
			
			</div><!-- /.content -->
			
			<?php get_sidebar(); ?>
		</div>
			
	<?php elseif( 'grid' == $type ) : ?>
			
		<div class="row">
			<div class="col-sm-12 content">
			
				<div class="blog-posts grid-blog col3">
					<?php 
						if ( $block_query->have_posts() ) : while ( $block_query->have_posts() ) : $block_query->the_post();
							
							/**
							 * Get blog posts by blog layout.
							 */
							get_template_part('loop/content-post', 'grid');
						
						endwhile;	
						else : 
							
							/**
							 * Display no posts message if none are found.
							 */
							get_template_part('loop/content','none');
							
						endif;
					?>
				</div><!-- /.blog-posts -->
				
				<?php
					if( 1 == $pagination )
						echo function_exists('ebor_pagination') ? ebor_pagination($block_query->max_num_pages) : posts_nav_link();
						
					wp_reset_query();
				?>
			
			</div><!-- /.content -->
		</div>
			
	<?php elseif( 'stripes' == $type ) : ?>
			
			<div class="blog no-sidebar">
				<?php 
					if ( $block_query->have_posts() ) : while ( $block_query->have_posts() ) : $block_query->the_post();
						
						( $block_query->current_post % 2 == 0 ) ? get_template_part('inc/content-wrapper','start') : get_template_part('inc/content-wrapper','start-dark');
						
						/**
						 * Get blog posts by blog layout.
						 */
						get_template_part('loop/content-post', 'stripes');
						
						/**
						 * Get Wrapper End - Uses get_template_part for simple child themeing.
						 */
						get_template_part('inc/content-wrapper','end'); 
					
					endwhile;	
					else : 
						
						/**
						 * Get Wrapper Start - Uses get_template_part for simple child themeing.
						 */
						get_template_part('inc/content-wrapper','start'); 
						
						/**
						 * Display no posts message if none are found.
						 */
						get_template_part('loop/content','none');
						
						/**
						 * Get Wrapper End - Uses get_template_part for simple child themeing.
						 */
						get_template_part('inc/content-wrapper','end'); 
						
					endif;
				?>
				
				<?php if( 1 == $pagination && ebor_pagination($block_query->max_num_pages) ) : ?>
					<div class="dark-wrapper">
						<div class="container inner">
							<div class="thin">
								<?php
									/**
									 * Post pagination, use ebor_pagination() first and fall back to default
									 */
									echo function_exists('ebor_pagination') ? ebor_pagination($block_query->max_num_pages) : posts_nav_link();
								?>
							</div>
						</div>
					</div>
				<?php endif; wp_reset_query(); ?>
				
			</div>
			
	<?php elseif( 'classic' == $type ) : ?>
			
		<div class="row">
			<div class="col-sm-12 content">
			
				<div class="blog-posts classic-blog">
					<?php 
						if ( $block_query->have_posts() ) : while ( $block_query->have_posts() ) : $block_query->the_post();
							
							/**
							 * Get blog posts by blog layout.
							 */
							get_template_part('loop/content-post', 'classic');
						
						endwhile;	
						else : 
							
							/**
							 * Display no posts message if none are found.
							 */
							get_template_part('loop/content','none');
							
						endif;
					?>
				</div><!-- /.blog-posts -->
			
				<?php
					if( 1 == $pagination )
						echo function_exists('ebor_pagination') ? ebor_pagination($block_query->max_num_pages) : posts_nav_link();
						
					wp_reset_query();
				?>
			
			</div><!-- /.content -->
		</div>
			
	<?php elseif( 'classic-sidebar' == $type ) : ?>
			
		<div class="row">
			<div class="col-sm-8 content">
			
				<div class="blog-posts classic-blog">
					<?php 
						if ( $block_query->have_posts() ) : while ( $block_query->have_posts() ) : $block_query->the_post();
							
							/**
							 * Get blog posts by blog layout.
							 */
							get_template_part('loop/content-post', 'classic');
						
						endwhile;	
						else : 
							
							/**
							 * Display no posts message if none are found.
							 */
							get_template_part('loop/content','none');
							
						endif;
					?>
				</div><!-- /.blog-posts -->
			
				<?php
					if( 1 == $pagination )
						echo function_exists('ebor_pagination') ? ebor_pagination($block_query->max_num_pages) : posts_nav_link();
						
					wp_reset_query();
				?>
			
			</div><!-- /.content -->
			
			<?php get_sidebar(); ?>
		</div>
			
	<?php elseif( 'classic-half' == $type ) : ?>
			
			<div class="latest-blog-wrapper">
			
				<div class="latest-blog isotope isotope js-isotope row" data-isotope-options='{ "layoutMode": "fitRows", "itemSelector": ".post" }'>
					<?php 
						if ( $block_query->have_posts() ) : while ( $block_query->have_posts() ) : $block_query->the_post();
						
							/**
							 * Get blog posts by blog layout.
							 */
							get_template_part('loop/content-post', 'classic-half');
						
						endwhile;	
						else : 
							
							/**
							 * Display no posts message if none are found.
							 */
							get_template_part('loop/content','none');
							
						endif;
					?>
				</div>
				
				<?php
					if( 1 == $pagination )
						echo function_exists('ebor_pagination') ? ebor_pagination($block_query->max_num_pages) : posts_nav_link();
						
					wp_reset_query();
				?>
			
			</div>
			
	<?php elseif( 'classic-full' == $type ) : ?>
			
		<div class="row">
			<div class="col-sm-12 content">
			
				<div class="blog-posts classic-blog">
					<?php 
						if ( $block_query->have_posts() ) : while ( $block_query->have_posts() ) : $block_query->the_post();
							
							/**
							 * Get blog posts by blog layout.
							 */
							get_template_part('loop/content-post', 'classic-full');
						
						endwhile;	
						else : 
							
							/**
							 * Display no posts message if none are found.
							 */
							get_template_part('loop/content','none');
							
						endif;
					?>
				</div><!-- /.blog-posts -->
			
				<?php
					if( 1 == $pagination )
						echo function_exists('ebor_pagination') ? ebor_pagination($block_query->max_num_pages) : posts_nav_link();
						
					wp_reset_query();
				?>
			
			</div><!-- /.content -->
		</div>
			
	<?php elseif( 'classic-sidebar-full' == $type ) : ?>
			
		<div class="row">
			<div class="col-sm-8 content">
			
				<div class="blog-posts classic-blog">
					<?php 
						if ( $block_query->have_posts() ) : while ( $block_query->have_posts() ) : $block_query->the_post();
							
							/**
							 * Get blog posts by blog layout.
							 */
							get_template_part('loop/content-post', 'classic-full');
						
						endwhile;	
						else : 
							
							/**
							 * Display no posts message if none are found.
							 */
							get_template_part('loop/content','none');
							
						endif;
					?>
				</div><!-- /.blog-posts -->
			
				<?php
					if( 1 == $pagination )
						echo function_exists('ebor_pagination') ? ebor_pagination($block_query->max_num_pages) : posts_nav_link();
						
					wp_reset_query();
				?>
			
			</div><!-- /.content -->
			
			<?php get_sidebar(); ?>
		</div>
			
	<?php elseif( 'classic-half-full' == $type ) : ?>
			
			<div class="latest-blog-wrapper">
			
				<div class="latest-blog isotope isotope js-isotope row" data-isotope-options='{ "layoutMode": "fitRows", "itemSelector": ".post" }'>
					<?php 
						if ( $block_query->have_posts() ) : while ( $block_query->have_posts() ) : $block_query->the_post();
						
							/**
							 * Get blog posts by blog layout.
							 */
							get_template_part('loop/content-post', 'classic-half-full');
						
						endwhile;	
						else : 
							
							/**
							 * Display no posts message if none are found.
							 */
							get_template_part('loop/content','none');
							
						endif;
					?>
				</div>
				
				<?php
					if( 1 == $pagination )
						echo function_exists('ebor_pagination') ? ebor_pagination($block_query->max_num_pages) : posts_nav_link();
						
					wp_reset_query();
				?>
			
			</div>
			
	<?php	
		endif;
	}//end block
	
}//end class